#include <iostream>
#include <array>

constexpr int is_prime(int p, int i) noexcept {
    if (p == 0 && i < 2)
        return 1;
    return  (p % i) && is_prime((i > 2 ? p : 0), i - 1);
};
constexpr int next_prime(int k) noexcept {
    if (!is_prime(k + 1, k))
        return next_prime(k + 1);
    return k + 1;
};
constexpr int k_prime(int k) noexcept {
    int prim = 2;
    for (int i = 0; i < k; ++i)
        prim = next_prime(prim);
    return prim;
};

/**
 * Variadic template for a recursive helper struct.
 */
constexpr int TABLE_SIZE = 10;

template<int INDEX = 0, int ...D>
struct Helper : Helper<INDEX + 1, D..., k_prime(INDEX)> { };

/**
 * Specialization of the template to end the recursion when the table size reaches TABLE_SIZE.
 */
template<int ...D>
struct Helper<TABLE_SIZE, D...> {
    static constexpr std::array<int, TABLE_SIZE> table = { D... };
};

constexpr std::array<int, TABLE_SIZE> table = Helper<>::table;

int main() {
    for (int i=0; i < TABLE_SIZE; i++) {
        std::cout << table[i]  << std::endl; // run time use
    }
}